@@ -3,14 +3,17 @@ from graphgallery.data_type import *
 
 # modules
 from graphgallery import nn
+from graphgallery import gallery
 from graphgallery import utils
 from graphgallery import sequence
 from graphgallery import data
+from graphgallery import datasets
 from graphgallery import backend
 from graphgallery import functional
 
+from .version import __version__
 
-__version__ = '0.5.0'
-
-__all__ = ['graphgallery', 'nn', 'utils', 'sequence', 'data',
-           'backend', 'functional', '__version__']
+__all__ = [
+    'graphgallery', 'nn', 'gallery', 'utils', 'sequence', 'data', 'datasets',
+    'backend', 'functional', '__version__'
+]
