@@ -2,4 +2,4 @@ from .layers import *
 from .models import *
 from .functions import *
 from .init import *
-from .gallery import *
\ No newline at end of file
+from .metrics import *
