@@ -1,5 +1,6 @@
 from .torch_keras import TorchKeras
+from .tf_keras import TFKeras
 from . import tensorflow
 from . import pytorch
 
-__all__ = ['TorchKeras']
+__all__ = ['TorchKeras', 'TFKeras']
