@@ -5,17 +5,21 @@ from torch.nn import Module, ModuleList, Dropout
 
 from graphgallery.nn.models import TorchKeras
 from graphgallery.nn.layers.pytorch.get_activation import get_activation
+from graphgallery.nn.metrics.pytorch import Accuracy
 
 from dgl.nn.pytorch import GraphConv
 
 
 class GCN(TorchKeras):
-    def __init__(self, in_channels, out_channels,
+    def __init__(self,
+                 in_channels,
+                 out_channels,
                  hiddens=[16],
                  activations=['relu'],
                  dropout=0.5,
                  weight_decay=5e-4,
-                 lr=0.01, use_bias=True):
+                 lr=0.01,
+                 use_bias=True):
 
         super().__init__()
 
@@ -23,17 +27,21 @@ class GCN(TorchKeras):
 
         inc = in_channels
         for hidden, activation in zip(hiddens, activations):
-            act = get_activation(activation)
-            layer = GraphConv(inc, hidden, activation=act, bias=use_bias)
+            layer = GraphConv(inc,
+                              hidden,
+                              activation=get_activation(activation),
+                              bias=use_bias)
             self.layers.append(layer)
             inc = hidden
         # output layer
         self.layers.append(GraphConv(inc, out_channels))
 
         self.dropout = Dropout(p=dropout)
-        self.loss_fn = torch.nn.CrossEntropyLoss()
-        self.optimizer = optim.Adam(self.parameters(), lr=lr,
-                                    weight_decay=weight_decay)
+        self.compile(loss=torch.nn.CrossEntropyLoss(),
+                     optimizer=optim.Adam(self.parameters(),
+                                          lr=lr,
+                                          weight_decay=weight_decay),
+                     metrics=[Accuracy()])
 
     def forward(self, inputs):
         x, g, indx = inputs
