@@ -1,4 +1,4 @@
-from tensorflow.keras import Model, Input
+from tensorflow.keras import Input
 from tensorflow.keras.layers import Dropout, Dense
 from tensorflow.keras.optimizers import Adam
 from tensorflow.keras import regularizers
@@ -6,16 +6,17 @@ from tensorflow.keras.losses import SparseCategoricalCrossentropy
 
 from graphgallery.nn.layers.tensorflow import GraphConvolution, Gather
 from graphgallery import floatx, intx
+from graphgallery.nn.models import TFKeras
 
 
-class FastGCN(Model):
+class FastGCN(TFKeras):
 
     def __init__(self, in_channels, out_channels,
                  hiddens=[32], activations=['relu'], dropout=0.5,
                  weight_decay=5e-4, lr=0.01, use_bias=False):
 
         x = Input(batch_shape=[None, in_channels],
-                  dtype=floatx(), name='attr_matrix')
+                  dtype=floatx(), name='node_attr')
         adj = Input(batch_shape=[None, None], dtype=floatx(),
                     sparse=True, name='adj_matrix')
 
