@@ -1,13 +1,14 @@
-from tensorflow.keras import Model, Input
+from tensorflow.keras import Input
 from tensorflow.keras.layers import Dropout, Dense
 from tensorflow.keras.optimizers import Adam
 from tensorflow.keras import regularizers
 from tensorflow.keras.losses import SparseCategoricalCrossentropy
 
 from graphgallery import floatx, intx
+from graphgallery.nn.models import TFKeras
 
 
-class SGC(Model):
+class SGC(TFKeras):
 
     def __init__(self, in_channels,
                  out_channels, hiddens=[],
@@ -21,7 +22,7 @@ class SGC(Model):
                                " Or you can set both of them to `[]`.")
 
         x = Input(batch_shape=[None, in_channels],
-                  dtype=floatx(), name='attr_matrix')
+                  dtype=floatx(), name='node_attr')
 
         h = x
         for hidden, activation in zip(hiddens, activations):
